@@ -5,11 +5,11 @@ Contains the Marmousi class.
 """
 import cv2
 import numpy as np
-import matplotlib.pyplot as plt
+from pyawd import VelocityModel2D
 from pyawd._marmousi_data import _get_marmousi_data
 
 
-class Marmousi:
+class Marmousi(VelocityModel2D):
     """
     Represents the Marmousi velocity field. The maximal resolution is (955px*955px). This is only available in 2D.
     """
@@ -24,20 +24,6 @@ class Marmousi:
         """
         self.raw_data = _get_marmousi_data()
         self.raw_nx = self.raw_data.shape[0]
-        self.nx = min(nx, self.raw_nx)
+        super().__init__(min(nx, self.raw_nx))
         self.data = cv2.resize(self.raw_data, (nx, nx))
         self.data = self.data / (np.max(self.data) * 10)
-
-    def get_data(self) -> np.ndarray:
-        """
-        Returns:
-            - self.data: the velocity field
-        """
-        return self.data
-
-    def plot(self):
-        """
-        Plots the field
-        """
-        plt.imshow(self.data)
-        plt.show()
