@@ -36,4 +36,6 @@ class VelocityModel2D(VelocityModel):
         Plots the field
         """
         plt.imshow(self.data)
+        plt.colorbar()
+        plt.tight_layout()
         plt.show()
